Module types

Module types 

Functions

additional_properties_value_type
Resolve an additionalProperties declaration to the value type T of the resulting HashMap<String, T>.
is_string_enum
Returns true when the schema is a string with enumeration values.
ref_to_ident
schema_to_rust_type
Map an OpenAPI Schema (or $ref) to a Rust type TokenStream.
schema_to_rust_type_ctx
Context-aware variant of schema_to_rust_type.
string_enum_values
Extract enum values from a string schema (skipping None entries).